# Python Library for PION
Created - 26|08|2019,
Modified - 28|03|2022

Welcome to the Python Library that does post-processing on the .Silo simulation data files outputted from PION. The library works on nested-grid and uniform-grid, and 3D and 2D Silo files.

# Install via pip:

You can now install PyPion via PyPi:

* Just run `python3 -m pip install pypion`

In some cases you may need to use `sudo` or install pip with: `sudo apt install python3-pip`

*Note: This is still in testing phase so errors may occur when installing. Please report problems to green@cp.dias.ie

# Install Silo package for python3:

The install script for SIlo can be found at /src/silo/ in this repository. Please download it to ~/.local/silo on your computer and install it there using `bash install_silo.sh` 

# Info on how to get started

* Example usage can be found at: [https://www.pion.ie/docs/python.html](https://www.pion.ie/docs/python.html)

* Check out the [Wiki](https://git.dias.ie/compastro/pion_python/-/wikis/home) for more detailed usage.

* How to use the PyPion docker image at: [https://www.pion.ie/docs/python.html](https://www.pion.ie/docs/python.html)


# Developers/Maintainers:

* Samuel Green - green@cp.dias.ie
* Jonathan Mackey

